@@ -8,7 +8,11 @@ from notion.client import NotionClient
 
 from enex2notion.cli_wkhtmltopdf import ensure_wkhtmltopdf
 from enex2notion.enex_parser import iter_notes
-from enex2notion.enex_uploader import get_import_root, upload_note
+from enex2notion.enex_uploader import (
+    NoteUploadFailException,
+    get_import_root,
+    upload_note,
+)
 from enex2notion.enex_uploader_modes import get_notebook_database, get_notebook_page
 from enex2notion.note_parser import parse_note
 from enex2notion.version import __version__
@@ -36,6 +40,20 @@ class DoneFile(object):
             f.write(f"{note_hash}\n")
 
 
+def _upload_note(notebook_root, note, note_blocks):
+    for attempt in range(5):
+        try:
+            upload_note(notebook_root, note, note_blocks)
+        except NoteUploadFailException:
+            if attempt == 4:
+                raise
+            logger.warning(
+                f"Failed to upload note '{note.title}' to Notion! Retrying..."
+            )
+            continue
+        break
+
+
 class EnexUploader(object):
     def __init__(
         self,
@@ -44,12 +62,14 @@ class EnexUploader(object):
         mode_webclips: str,
         done_file: Path,
         add_meta: bool,
+        add_pdf_preview: bool,
     ):
         self.import_root = import_root
         self.mode = mode
         self.mode_webclips = mode_webclips
         self.done_hashes = DoneFile(done_file) if done_file else set()
         self.add_meta = add_meta
+        self.add_pdf_preview = add_pdf_preview
 
     def upload(self, enex_file: Path):
         logger.info(f"Processing notebook '{enex_file.stem}'...")
@@ -66,13 +86,16 @@ class EnexUploader(object):
                 continue
 
             if notebook_root is not None:
-                upload_note(notebook_root, note, note_blocks)
+                _upload_note(notebook_root, note, note_blocks)
                 self.done_hashes.add(note.note_hash)
 
     def _parse_note(self, note):
         try:
             return parse_note(
-                note, mode_webclips=self.mode_webclips, is_add_meta=self.add_meta
+                note,
+                mode_webclips=self.mode_webclips,
+                is_add_meta=self.add_meta,
+                is_add_pdf_preview=self.add_pdf_preview,
             )
         except Exception:
             logger.error(f"Unhandled exception while parsing note '{note.title}'!")
@@ -112,6 +135,7 @@ def cli(argv):
         mode_webclips=args.mode_webclips,
         done_file=args.done_file,
         add_meta=args.add_meta,
+        add_pdf_preview=args.add_pdf_preview,
     )
 
     for enex_input in args.enex_input:
@@ -165,6 +189,14 @@ def parse_args(argv):
                 " (default: TXT)"
             ),
         },
+        "--add-pdf-preview": {
+            "action": "store_true",
+            "default": False,
+            "help": (
+                "include preview image with PDF webclips for gallery view thumbnail"
+                " (works only with --mode-webclips=PDF)"
+            ),
+        },
         "--add-meta": {
             "action": "store_true",
             "default": False,
